#!/bin/sh

# This script helps me process screenshots I have for work.  A lot of
# them includes complex data suitable for JPEG compression.  Note that
# usually a screen with simple contiguous blocks of a single colour is
# best off as PNG.  More complex visuals like photos are better off
# with lossy compression like JPEG.

TRASH=/tmp/.pns_trash/

# Check that a configuration file is present
if ! [ -f "pns.conf" ]; then
    echo "No pns.conf in current directory.";
    exit;
fi

# Verify that splitalbum is available
if [ -z "$(which splitalbum 2>/dev/null)" ]; then
    echo "splitalbum not installed.  (That's another script by me.)";
    echo "Disabling feature and operating without it."
    SPLITALBUM='n'
else
    SPLITALBUM='y'
fi

# Validate configuration: check that exactly one 'destination=' key is defined
NUMDESTINATIONKEYS=$(grep "^destination=" pns.conf | wc -l) 

if [ "${NUMDESTINATIONKEYS}" == 0 ]; then
    echo "No 'destination' key set in pns.conf.  Add a line like:"
    echo "destination=/some/valid/directory"
    exit;
elif [ "${NUMDESTINATIONKEYS}" != 1 ]; then
    echo "Multiple 'destination' keys set in pns.conf.  Comment out/remove all but one.";
    exit;
fi

# Verify that destination directory exists
DESTINATION=$(grep '^destination=' pns.conf | sed -r -e 's,^[^=]*=,,g')

if ! [ -d "${DESTINATION}" ]; then
    echo "Destination '${DESTINATION}' does not exist.  Mount it?"
    exit;
fi

# Verify that there are PNGs to convert
NUMPNGS=$(ls *.png 2>/dev/null | wc -l)
if [ "${NUMPNGS}" == "0" ]; then
    echo "No PNGs to convert.  Note we only consider .png, not .PNG"
    exit;
fi
echo "Num PNGs: ${NUMPNGS}"

# Let the user remove PNGs they don't want to convert
echo "Remove screenshots to keep as PNG and then press enter";
read;

# Convert PNGs to JPGs using ImageMagick's convert, show space before...
echo "Space before:" $(du -sk . | awk ' { print $1 } ') "kB"
test -d "${TRASH}" || mkdir "${TRASH}"
for i in *.png; do
    echo "Converting '$i' to '$i.jpg'"
    convert "$i"{,.jpg} 2>/dev/null && mv "$i" "${TRASH}/"
done
echo "  old PNGs moved to /tmp/";

# Verify that JPGs were converted (could test that NUMJPGS == NUMPNGS, but we might have other JPGs in here
# Show space after
NUMJPGS=$(ls *.jpg 2>/dev/null | wc -l)
if [ "${NUMJPGS}" == "0" ]; then
    echo "ERROR: No JPGs actually converted.  Uh oh!"
    exit;
fi
echo "Space after:" $(du -sk . | awk ' { print $1 } ') "kB";

# Split screenshots into directories by date
(test -d tmp || mkdir tmp) && 
mv *jpg tmp/ &&
if [ "${SPLITALBUM}" == 'y' ]; then
    echo "Splitting screenshots into directories by date..." && 
    echo "==splitalbum $(date '+%Y-%m-%d %H:%M:%S')==" >> pns.log &&
    splitalbum tmp/ tmp/ >> pns.log 2>&1;
else
    echo "splitalbum not installed: not splitting screenshots into directories by date"
fi &&
# Copy files to the destination using rsync, removing the source files once copied
echo -n "Copying files from tmp/ to ${DESTINATION}/..." &&
echo "==RSYNC $(date '+%Y-%m-%d %H:%M:%S')==" >> pns.log &&
rsync -av --progress --remove-source-files tmp/ "${DESTINATION}/" >> pns.log 2>&1 && echo "Success" || echo "Error, check pns.log"

rmdir tmp/* tmp/ 2>/dev/null
